TexturepackerLoader extension

on
  • Game

Methods

atlasFromAssets(String assetsPath, {Images? images, AssetsCache? assets, bool useOriginalSize = true, List<String> whiteList = const [], String assetsPrefix = 'images'}) Future<TexturePackerAtlas>

Available on Game, provided by the TexturepackerLoader extension

Loads the specified pack file from assets Uses the parent directory of the pack file to find the page images.
atlasFromStorage(String storagePath, {Images? images, bool useOriginalSize = true, List<String> whiteList = const []}) Future<TexturePackerAtlas>

Available on Game, provided by the TexturepackerLoader extension

Loads the specified pack file from storage Uses the parent directory of the pack file to find the page images.